
import * as angular from 'angular';
import { NwfFormControl, NwfFormSection, NwfFormLabel, NwfFormControlFactory, NwfFormSectionFactory, NwfFormLabelFactory } from './components/formControl-directives';
import { NwfFormRow, NwfInlineBlockForm, NwfInlineForm, NwfFormRowFactory, NwfInlineBlockFormFactory, NwfInlineFormFactory } from './components/formLayout-directives';
import { NwfFormElement, NwfFormElementFactory, NwfFormDirtyCheck, NwfFormDirtyCheckFactory } from './components/formValidation-directives';
import { IsRequiredValidator, IsRequiredValidatorFactory} from './validators/isRequired-directive';
import { IsNumberValidator, IsNumberValidatorFactory } from './validators/isNumber-directive';
import { IsEmailValidator, IsEmailValidatorFactory } from './validators/isEmail-directive';
import { IsPatternValidator, IsPatternValidatorFactory } from './validators/isPattern-directive';
import { IsSameValidator, IsSameValidatorFactory } from './validators/isSame-directive';



export default class FormModule  {

    static NAME:string = 'nwfFormModule';
    static DEPENDENCIES:Array<string> = [];
    private native:angular.IModule;

    constructor() {
        this.native = angular.module(FormModule.NAME, FormModule.DEPENDENCIES);
        this.native.directive(NwfFormControl.NAME, NwfFormControlFactory);
        this.native.directive(NwfFormSection.NAME, NwfFormSectionFactory);
        this.native.directive(NwfFormLabel.NAME, NwfFormLabelFactory);
        this.native.directive(NwfFormRow.NAME, NwfFormRowFactory);
        this.native.directive(NwfInlineBlockForm.NAME, NwfInlineBlockFormFactory);
        this.native.directive(NwfInlineForm.NAME, NwfInlineFormFactory);
        this.native.directive(NwfFormElement.NAME, NwfFormElementFactory);
        this.native.directive(NwfFormDirtyCheck.NAME, NwfFormDirtyCheckFactory);
        this.native.directive(IsRequiredValidator.NAME, IsRequiredValidatorFactory);
        this.native.directive(IsNumberValidator.NAME, IsNumberValidatorFactory);
        this.native.directive(IsEmailValidator.NAME, IsEmailValidatorFactory);
        this.native.directive(IsPatternValidator.NAME, IsPatternValidatorFactory);
        this.native.directive(IsSameValidator.NAME, IsSameValidatorFactory);

        /* housed here for now, it is used on the <html> tag to add a wrapper class for browser specific styling */
        this.native.directive('uaCss',() => {

            return {
                restrict: 'A',
                controller: ($element, $window) => {
                    var element = $element.get(0);
                    var ua = navigator.userAgent;
                    var ua_css = 'is-other';
                    if ($window.ActiveXObject || "ActiveXObject" in window) {
                        ua_css = 'is-ie';
                    } else if (ua.toLowerCase().indexOf('firefox') > -1) {
                        ua_css = 'is-firefox';
                    } else if (/WebKit/.test(ua)) {
                        ua_css = 'is-webkit';
                    }
                    element.classList.add(ua_css);
                }
            };

        });
    }

}
