/**
 * Copyright (c) 2015 NetApp
 * All rights reserved
 *
 * @ngdoc directive
 * @name nwfHelp
 * @description
 * Help directive is used to provide context-sensitive help for applications using webworks.
 * This uses WWHAPI from webworks help JavaScript based APIs
 *
 * An application needs to provide base context for the help on its server by using nwfConfigProvider.
 * It can then continue to use the directive by passing in GUID for help within it's screens.
 * @example
 *
 *  nwfConfigProvider.setHelpContext('GUID-646AA4A1-ED85-48B1-9AD1-018D44F055B8');
 * <legend class="form-legend" nwf-help guid="GUID-CEA1F463-AE33-4054-8C5E-2A128DC5EF24">NTP Server</legend>
 */

export class NwfHelp implements angular.IDirective {

    static NAME: string = 'nwfHelp';

    restrict = 'EA';
    scope = {
        guid: '@',
        showIcon: '@'
    };

    controller = ["$element", "$scope", "nwfConfig", "nwfHelpService", "$compile", function ($element: angular.IAugmentedJQuery, $scope, nwfConfig, nwfHelpService, $compile) {

        var helpable = $element.get(0);

        var guid = $scope.guid;

        var showIcon = $scope.showIcon == "false" ? false : true;

        //Get the base context ID for the application.
        var baseContextId = nwfConfig.getHelpContext();
        var launcher = function () {
            if (typeof (guid) != "undefined") {
                nwfHelpService.helpDirectiveWindow.fDisplayHelpWithNavigation(baseContextId, guid);
            } else {
                nwfHelpService.helpDirectiveWindow.fDisplayHelpContents();
            }
        };

        var makeHelpableLink = function () {
            helpable.classList.add('nwf-help-link');
            helpable.addEventListener('click', launcher);
        };
        if (showIcon) {
            var template = '<nwf-icon icon-class="icon-Help" class="nwf-help"></nwf-icon>';
            var linkFn = $compile(template);
            var content = linkFn($scope);
            $element.append(content);
            var helpIcon = content.get(0);
            $scope.$watch('guid', function (newVal) {
                //just tack on the guid on the data-netapp-id
                var naid = 'data-netapp-id';
                var newNaid = 'nwf-help-guid-' + newVal;
                helpIcon.setAttribute(naid, newNaid);
            });
            helpIcon.addEventListener('click', launcher);
            /* If I am a link, I want it to be clickable too */
            if (helpable.tagName == 'A') {
                makeHelpableLink();
            }
        } else {
            makeHelpableLink();
        }

        $element.on('$destroy', function () {
            helpable.removeEventListener('click', launcher);
        });

    }];

}


// export factory function
export function NwfHelpFactory(): NwfHelp {
    return new NwfHelp();
}
