import * as ng from 'angular';

export default class LeftNavController {

    private navData;
    private isNavMinimized = false;
    private nav: HTMLElement;

    static $inject = ['$element', 'IFramerService', '$scope', '$rootScope'];

    constructor(private $element, private IFramerService, private $scope, private $rootScope) {
        /* Set my initial state */
        if (!this.isNavMinimized) {
            this.showNav();
        }

        var resizeHandle;
        this.nav = this.$element.find('nav.nav').get(0);
        ng.element(window).bind('resize', () => {
            clearTimeout(resizeHandle);
            resizeHandle = setTimeout( () => {
                this.afterResizeEnd();
            }, 150);
        });
        this.afterResizeEnd();
    }

    afterResizeEnd() {
        var el = this.nav;
        if (el.offsetHeight < el.scrollHeight) {
            // your element is overflowing
            el.classList.add('is-overflowing');
        } else {
            // your element IS not overflow
            el.classList.remove('is-overflowing');
        }
    }

    iFramerGo() {
        this.$scope.$emit('iframer.show', this.IFramerService.getIframeSrc(), 'global');
    }

    toggleItem(event) {
        var $self = $(event.currentTarget);
        var $li = $self.closest('li');

        $li.toggleClass('active').siblings().removeClass('active');
        $li.find('.sub-nav').attr('aria-hidden', function (i, attr) {
            return attr == 'true' ? 'false' : 'true';
        });
        var me = $li.find('.sub-nav');

        me.slideToggle({
            start: function () {
                $li.parent().find('.sub-nav').not(me).slideUp();
            },
            complete: () => {
                this.afterResizeEnd();
            }
        });
    }

    toggleNav() {
        var showMe = this.isNavMinimized = !this.isNavMinimized;
        if (!showMe) {
            this.showNav();
        } else {
            this.hideNav();
        }
    }

    onItemMouseEnter() {
        if (this.isNavMinimized) {
            this.showNav();
        }
    }

    hideNav() {
        this.showOrHideNav(false);
    }

    showNav() {
        this.showOrHideNav(true);
    }

    private showOrHideNav(showOrHide: boolean) {
        this.isNavMinimized = !showOrHide;
        var thisEl = this.$element;
        var thisSubNav = this.$element.find('.sub-nav');
        var body = ng.element('body');
        if (showOrHide === true) {
            thisEl.removeClass('resize');
            thisSubNav.removeClass('hide');
            body.addClass('nav-is-active');
        } else {
            /* hide the leftnav (full width) */
            thisEl.addClass('resize');
            thisSubNav.addClass('hide');
            body.removeClass('nav-is-active');
        }
        setTimeout( () =>  this.$rootScope.$broadcast('leftNav-resize'), 310);
    }

}
